@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from dataclasses import dataclass
-from typing import List, Literal
+from dataclasses import dataclass, fields
+from typing import Any, List, Literal
 
 from todoist_api_python.utils import get_url_for_task
 
@@ -9,7 +9,7 @@ VIEW_STYLE = Literal["list", "board"]
 
 
 @dataclass
-class Project(object):
+class Project:
     color: str
     comment_count: int
     id: str
@@ -17,6 +17,7 @@ class Project(object):
     is_inbox_project: bool
     is_shared: bool
     is_team_inbox: bool
+    can_assign_tasks: bool
     name: str
     order: int
     parent_id: str | None
@@ -33,6 +34,7 @@ class Project(object):
             is_inbox_project=obj.get("is_inbox_project"),
             is_shared=obj["is_shared"],
             is_team_inbox=obj.get("is_team_inbox"),
+            can_assign_tasks=obj.get("can_assign_tasks"),
             name=obj["name"],
             order=obj.get("order"),
             parent_id=obj.get("parent_id"),
@@ -42,7 +44,7 @@ class Project(object):
 
 
 @dataclass
-class Section(object):
+class Section:
     id: str
     name: str
     order: int
@@ -59,7 +61,7 @@ class Section(object):
 
 
 @dataclass
-class Due(object):
+class Due:
     date: str
     is_recurring: bool
     string: str
@@ -110,7 +112,7 @@ class Due(object):
 
 
 @dataclass
-class Task(object):
+class Task:
     assignee_id: str | None
     assigner_id: str | None
     comment_count: int
@@ -128,16 +130,21 @@ class Task(object):
     project_id: str
     section_id: str | None
     url: str
+    duration: Duration | None
 
     sync_id: str | None = None
 
     @classmethod
     def from_dict(cls, obj):
         due: Due | None = None
+        duration: Duration | None = None
 
         if obj.get("due"):
             due = Due.from_dict(obj["due"])
 
+        if obj.get("duration"):
+            duration = Duration.from_dict(obj["duration"])
+
         return cls(
             assignee_id=obj.get("assignee_id"),
             assigner_id=obj.get("assigner_id"),
@@ -156,6 +163,7 @@ class Task(object):
             project_id=obj["project_id"],
             section_id=obj["section_id"],
             url=obj["url"],
+            duration=duration
         )
 
     def to_dict(self):
@@ -183,15 +191,20 @@ class Task(object):
             "section_id": self.section_id,
             "sync_id": self.sync_id,
             "url": self.url,
+            "duration": self.duration
         }
 
     @classmethod
     def from_quick_add_response(cls, obj):
         due: Due | None = None
+        duration: Duration | None = None
 
         if obj.get("due"):
             due = Due.from_quick_add_response(obj)
 
+        if obj.get("duration"):
+            duration = Duration.from_dict(obj["duration"])
+
         return cls(
             assignee_id=obj.get("responsible_uid"),
             assigner_id=obj.get("assigned_by_uid"),
@@ -202,6 +215,7 @@ class Task(object):
             creator_id=obj["added_by_uid"],
             description=obj["description"],
             due=due,
+            duration=duration,
             id=obj["id"],
             labels=obj["labels"],
             order=obj["child_order"],
@@ -252,7 +266,7 @@ class QuickAddResult:
 
 
 @dataclass
-class Collaborator(object):
+class Collaborator:
     id: str
     email: str
     name: str
@@ -267,7 +281,7 @@ class Collaborator(object):
 
 
 @dataclass
-class Attachment(object):
+class Attachment:
     resource_type: str | None = None
 
     file_name: str | None = None
@@ -302,7 +316,7 @@ class Attachment(object):
 
 
 @dataclass
-class Comment(object):
+class Comment:
     attachment: Attachment | None
     content: str
     id: str
@@ -357,3 +371,86 @@ class AuthResult:
             access_token=obj["access_token"],
             state=obj["state"],
         )
+
+
+@dataclass
+class Item:
+    id: str
+    user_id: str
+    project_id: str
+    content: str
+    description: str
+    priority: int
+    child_order: int
+    collapsed: bool
+    labels: list[str]
+    checked: bool
+    is_deleted: bool
+    added_at: str
+    due: Due | None = None
+    parent_id: int | None = None
+    section_id: str | None = None
+    day_order: int | None = None
+    added_by_uid: str | None = None
+    assigned_by_uid: str | None = None
+    responsible_uid: str | None = None
+    sync_id: str | None = None
+    completed_at: str | None = None
+
+    @classmethod
+    def from_dict(cls, obj: dict[str, Any]) -> Item:
+        params = {f.name: obj[f.name] for f in fields(cls) if f.name in obj}
+        if (due := obj.get("due")) is not None:
+            params["due"] = Due.from_dict(due)
+
+        return cls(**params)
+
+
+@dataclass
+class ItemCompletedInfo:
+    item_id: str
+    completed_items: int
+
+    @classmethod
+    def from_dict(cls, obj: dict[str, Any]) -> ItemCompletedInfo:
+        return cls(**{f.name: obj[f.name] for f in fields(cls)})
+
+
+@dataclass
+class CompletedItems:
+    items: list[Item]
+    total: int
+    completed_info: list[ItemCompletedInfo]
+    has_more: bool
+    next_cursor: str | None = None
+
+    @classmethod
+    def from_dict(cls, obj: dict[str, Any]) -> CompletedItems:
+        return cls(
+            items=[Item.from_dict(v) for v in obj["items"]],
+            total=obj["total"],
+            completed_info=[
+                ItemCompletedInfo.from_dict(v) for v in obj["completed_info"]
+            ],
+            has_more=obj["has_more"],
+            next_cursor=obj.get("next_cursor"),
+        )
+
+
+@dataclass
+class Duration(object):
+    amount: int
+    unit: str
+
+    @classmethod
+    def from_dict(cls, obj):
+        return cls(
+            amount=obj["amount"],
+            unit=obj["unit"],
+        )
+
+    def to_dict(self):
+        return {
+            "amount": self.amount,
+            "unit": self.unit,
+        }
